diff --git a/chipset/cc256x/ant_cmds.h b/chipset/cc256x/ant_cmds.h
index d850fb77a..a6734da5d 100644
--- a/chipset/cc256x/ant_cmds.h
+++ b/chipset/cc256x/ant_cmds.h
@@ -39,7 +39,7 @@
 #define __ANT_CMDS_H
 
 #include <stdint.h>
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #if defined __cplusplus
 extern "C" {
diff --git a/doc/manual/docs/protocols.md b/doc/manual/docs/protocols.md
index cb54fe38e..89f61f69f 100644
--- a/doc/manual/docs/protocols.md
+++ b/doc/manual/docs/protocols.md
@@ -90,7 +90,7 @@ In a HCI command packet, the OpCode is followed by parameter total
 length, and the actual parameters. The OpCode of a command can be
 calculated using the OPCODE macro. BTstack provides the *hci_cmd_t*
 struct as a compact format to define HCI command packets, see 
-Listing [below](#lst:HCIcmdTemplate), and [include/btstack/hci_cmds.h]()
+Listing [below](#lst:HCIcmdTemplate), and [include/btstack/hci_cmd.h]()
 file in the source code. 
 
 ~~~~ {#lst:HCIcmdTemplate .c caption="{HCI command struct.}"}
diff --git a/example/daemon/l2cap-server.c b/example/daemon/l2cap-server.c
index 291a54f26..6967e851a 100644
--- a/example/daemon/l2cap-server.c
+++ b/example/daemon/l2cap-server.c
@@ -48,7 +48,7 @@
 
 #include "btstack_client.h"
 #include "btstack_run_loop_posix.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "classic/sdp_util.h"
 
 int l2cap_reg_fail = 0;
diff --git a/example/daemon/l2cap-throughput.c b/example/daemon/l2cap-throughput.c
index 97442aee0..6b364d202 100644
--- a/example/daemon/l2cap-throughput.c
+++ b/example/daemon/l2cap-throughput.c
@@ -48,7 +48,7 @@
 
 #include "btstack_client.h"
 #include "btstack_run_loop_posix.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #define PSM_TEST 0xdead
 #define PACKET_SIZE 1000
diff --git a/example/daemon/test.c b/example/daemon/test.c
index b08191dee..e306b348e 100644
--- a/example/daemon/test.c
+++ b/example/daemon/test.c
@@ -49,7 +49,7 @@
 #include "btstack_client.h"
 #include "btstack_run_loop.h"
 #include "btstack_run_loop_posix.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 // bd_addr_t addr = {0x00, 0x03, 0xc9, 0x3d, 0x77, 0x43 };  // Think Outside Keyboard
 // bd_addr_t addr = {0x00, 0x19, 0x1d, 0x90, 0x44, 0x68 };  // WiiMote
diff --git a/example/embedded/Makefile.inc b/example/embedded/Makefile.inc
index 2fcfe1db7..d20c51700 100644
--- a/example/embedded/Makefile.inc
+++ b/example/embedded/Makefile.inc
@@ -17,7 +17,7 @@ CORE += \
 
 COMMON += \
     hci.c			            \
-    hci_cmds.c		            \
+    hci_cmd.c		            \
     hci_dump.c		            \
     l2cap.c			            \
     l2cap_signaling.c	        \
diff --git a/example/embedded/gap_dedicated_bonding.c b/example/embedded/gap_dedicated_bonding.c
index 400827584..b88e69e2c 100644
--- a/example/embedded/gap_dedicated_bonding.c
+++ b/example/embedded/gap_dedicated_bonding.c
@@ -44,7 +44,7 @@
 #include <string.h>
 
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/example/embedded/gap_le_advertisements.c b/example/embedded/gap_le_advertisements.c
index de1b9284f..4c9845bee 100644
--- a/example/embedded/gap_le_advertisements.c
+++ b/example/embedded/gap_le_advertisements.c
@@ -50,7 +50,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #include "btstack_memory.h"
 #include "hci.h"
diff --git a/example/embedded/gatt_battery_query.c b/example/embedded/gatt_battery_query.c
index e8425c161..9dfc814bc 100644
--- a/example/embedded/gatt_battery_query.c
+++ b/example/embedded/gatt_battery_query.c
@@ -46,7 +46,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "btstack_run_loop.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_util.h"
 #include "btstack-config.h"
 
diff --git a/example/embedded/gatt_browser.c b/example/embedded/gatt_browser.c
index 4e0e8a81b..164961eac 100644
--- a/example/embedded/gatt_browser.c
+++ b/example/embedded/gatt_browser.c
@@ -56,7 +56,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "btstack_run_loop.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_util.h"
 
 #include "btstack-config.h"
diff --git a/example/embedded/panu_demo.c b/example/embedded/panu_demo.c
index 1bd62854e..3bda6c38f 100644
--- a/example/embedded/panu_demo.c
+++ b/example/embedded/panu_demo.c
@@ -81,7 +81,7 @@
 #include <linux/if_tun.h>
 #endif
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/example/embedded/sdp_bnep_query.c b/example/embedded/sdp_bnep_query.c
index 4d35bd9d7..26ecc2263 100644
--- a/example/embedded/sdp_bnep_query.c
+++ b/example/embedded/sdp_bnep_query.c
@@ -51,7 +51,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/example/embedded/sdp_general_query.c b/example/embedded/sdp_general_query.c
index 78bd124c8..252bab665 100644
--- a/example/embedded/sdp_general_query.c
+++ b/example/embedded/sdp_general_query.c
@@ -54,7 +54,7 @@
 #include "classic/sdp_client.h"
 #include "classic/sdp_query_util.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/example/embedded/sdp_rfcomm_query.c b/example/embedded/sdp_rfcomm_query.c
index e7d1375ed..53fd45972 100644
--- a/example/embedded/sdp_rfcomm_query.c
+++ b/example/embedded/sdp_rfcomm_query.c
@@ -49,7 +49,7 @@
 #include <string.h>
 
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/example/embedded/spp_flowcontrol.c b/example/embedded/spp_flowcontrol.c
index f531b6c52..a85fa0b4b 100644
--- a/example/embedded/spp_flowcontrol.c
+++ b/example/embedded/spp_flowcontrol.c
@@ -49,7 +49,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/example/embedded/spp_streamer.c b/example/embedded/spp_streamer.c
index 7adb68372..97b03e421 100644
--- a/example/embedded/spp_streamer.c
+++ b/example/embedded/spp_streamer.c
@@ -49,7 +49,7 @@
 #include <string.h>
 
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/platform/daemon/btstack_client.h b/platform/daemon/btstack_client.h
index b011ec112..074a86152 100644
--- a/platform/daemon/btstack_client.h
+++ b/platform/daemon/btstack_client.h
@@ -47,7 +47,7 @@
 #ifndef __BTSTACK_CLIENT_H
 #define __BTSTACK_CLIENT_H
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "daemon_cmds.h"
 #include "btstack_run_loop.h"
 #include "btstack_util.h"
diff --git a/platform/daemon/daemon.c b/platform/daemon/daemon.c
index 253fbe520..24e95145a 100644
--- a/platform/daemon/daemon.c
+++ b/platform/daemon/daemon.c
@@ -59,7 +59,7 @@
 #include "btstack_linked_list.h"
 #include "btstack_run_loop.h"
 #include "btstack_run_loop_posix.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_version.h"
 
 #include "btstack_debug.h"
diff --git a/platform/daemon/daemon_cmds.c b/platform/daemon/daemon_cmds.c
index 8ca684577..24f2b9f86 100644
--- a/platform/daemon/daemon_cmds.c
+++ b/platform/daemon/daemon_cmds.c
@@ -36,7 +36,7 @@
  */
 
 /*
- *  hci_cmds.c
+ *  hci_cmd.c
  *
  *  Created by Matthias Ringwald on 7/23/09.
  */
diff --git a/platform/daemon/daemon_cmds.h b/platform/daemon/daemon_cmds.h
index 8bd05466d..9a0623a79 100644
--- a/platform/daemon/daemon_cmds.h
+++ b/platform/daemon/daemon_cmds.h
@@ -45,7 +45,7 @@
 #include <stdint.h>
 
 #include "bluetooth.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #if defined __cplusplus
 extern "C" {
diff --git a/port/arduino/BTstack.cpp b/port/arduino/BTstack.cpp
index fc946cb51..85d454400 100644
--- a/port/arduino/BTstack.cpp
+++ b/port/arduino/BTstack.cpp
@@ -18,7 +18,7 @@
 #include "btstack_memory.h"
 #include "hal_tick.h"
 #include "hal_cpu.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_util.h"
 #include "btstack_run_loop.h"
 #include "btstack_run_loop_embedded.h"
diff --git a/port/arduino/Makefile b/port/arduino/Makefile
index 577e47c31..1b371a11b 100644
--- a/port/arduino/Makefile
+++ b/port/arduino/Makefile
@@ -10,7 +10,7 @@ BTSTACK_PACKAGE=/tmp/btstack
 ARCHIVE=btstack-arduino-${VERSION}.zip
 
 SRC_FILES  = btstack_memory.c btstack_linked_list.c btstack_memory_pool.c run_loop.c 
-SRC_FILES += hci_dump.c hci.c hci_cmds.c  btstack_util.c l2cap.c
+SRC_FILES += hci_dump.c hci.c hci_cmd.c  btstack_util.c l2cap.c
 BLE_FILES  =  ad_parser.c att.c att_server.c att_dispatch.c att_db_util.c le_device_db_memory.c gatt_client.c
 BLE_FILES += sm.c ancs_client_lib.h ancs_client_lib.c
 PORT_FILES = btstack-config.h bsp_arduino_em9301.cpp BTstack.cpp BTstack.h
diff --git a/port/daemon/src/Makefile.in b/port/daemon/src/Makefile.in
index b53582af5..809ea4249 100644
--- a/port/daemon/src/Makefile.in
+++ b/port/daemon/src/Makefile.in
@@ -28,7 +28,7 @@ usb_sources = @USB_SOURCES@
 libBTstack_SOURCES =    \
     btstack.c           \
     socket_connection.c \
-    hci_cmds.c          \
+    hci_cmd.c          \
     daemon_cmds.c       \
     btstack_linked_list.c    \
     btstack_run_loop.c  \
diff --git a/port/ez430-rf2560/Makefile b/port/ez430-rf2560/Makefile
index 10568d725..433e0e097 100644
--- a/port/ez430-rf2560/Makefile
+++ b/port/ez430-rf2560/Makefile
@@ -53,7 +53,7 @@ COMMON = \
     hal_uart_dma.c            \
 	bt_control_cc256x.c       \
     hci.c			          \
-    hci_cmds.c		          \
+    hci_cmd.c		          \
     hci_transport_h4_ehcill_embedded.c \
 	remote_device_db_memory.c \
 
diff --git a/port/ez430-rf2560/example/ant-test.c b/port/ez430-rf2560/example/ant-test.c
index 4fa98b8fe..203f49f54 100644
--- a/port/ez430-rf2560/example/ant-test.c
+++ b/port/ez430-rf2560/example/ant-test.c
@@ -57,7 +57,7 @@
 #include "hal_usb.h"
 
 #include "ant_cmds.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 #include "btstack_util.h"
diff --git a/port/ez430-rf2560/example/spp_accel.c b/port/ez430-rf2560/example/spp_accel.c
index 726c685e8..fb34e3ee4 100644
--- a/port/ez430-rf2560/example/spp_accel.c
+++ b/port/ez430-rf2560/example/spp_accel.c
@@ -54,7 +54,7 @@
 #include "hal_compat.h"
 #include "hal_usb.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/port/ez430-rf2560/src/main.c b/port/ez430-rf2560/src/main.c
index 4465cdb80..d5db29a77 100644
--- a/port/ez430-rf2560/src/main.c
+++ b/port/ez430-rf2560/src/main.c
@@ -55,7 +55,7 @@
 #include "hal_compat.h"
 #include "hal_usb.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/port/ios/CocoaTouch/include/BTstack/BTInquiryViewController.h b/port/ios/CocoaTouch/include/BTstack/BTInquiryViewController.h
index 04d406d1e..2728d72bb 100644
--- a/port/ios/CocoaTouch/include/BTstack/BTInquiryViewController.h
+++ b/port/ios/CocoaTouch/include/BTstack/BTInquiryViewController.h
@@ -37,7 +37,7 @@
 
 #import <UIKit/UIKit.h>
 
-#include "hci_cmds.h" // for HCI_STATE
+#include "hci_cmd.h" // for HCI_STATE
 
 #define PREFS_REMOTE_NAME  @"RemoteName"
 #define PREFS_LINK_KEY     @"LinkKey"
diff --git a/port/ios/CocoaTouch/src/BTstackCocoaAppDelegate.m b/port/ios/CocoaTouch/src/BTstackCocoaAppDelegate.m
index a58968600..06e042586 100644
--- a/port/ios/CocoaTouch/src/BTstackCocoaAppDelegate.m
+++ b/port/ios/CocoaTouch/src/BTstackCocoaAppDelegate.m
@@ -47,7 +47,7 @@
 #include "btstack_client.h"
 #include "btstack_run_loop.h"
 #include "btstack_run_loop_cocoa.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 void packet_handler(uint8_t packet_type, uint16_t channel, uint8_t *packet, uint16_t size){
 }
diff --git a/port/ios/example/WiiMoteOpenGLDemo/Classes/WiiMoteOpenGLDemoAppDelegate.m b/port/ios/example/WiiMoteOpenGLDemo/Classes/WiiMoteOpenGLDemoAppDelegate.m
index 47f28326b..cf392ec78 100644
--- a/port/ios/example/WiiMoteOpenGLDemo/Classes/WiiMoteOpenGLDemoAppDelegate.m
+++ b/port/ios/example/WiiMoteOpenGLDemo/Classes/WiiMoteOpenGLDemoAppDelegate.m
@@ -42,7 +42,7 @@
 
 #import "btstack.h"
 #import "btstack_run_loop.h"
-#import <btstack/hci_cmds.h>
+#import <btstack/hci_cmd.h>
 
 @interface UIDevice (privateAPI)
 -(BOOL) isWildcat;
diff --git a/port/ios/src/Makefile b/port/ios/src/Makefile
index 695b0f3d5..8957f4357 100644
--- a/port/ios/src/Makefile
+++ b/port/ios/src/Makefile
@@ -23,7 +23,7 @@ libBTstack_FILES = \
 	btstack_run_loop_cocoa.m \
 	btstack_run_loop_posix.c \
 	daemon_cmds.c \
-	hci_cmds.c \
+	hci_cmd.c \
 	hci_dump.c \
 	sdp_util.c \
 	socket_connection.c \
diff --git a/port/msp-exp430f5438-cc2564b/Makefile b/port/msp-exp430f5438-cc2564b/Makefile
index dc6af7fd0..99be67d16 100644
--- a/port/msp-exp430f5438-cc2564b/Makefile
+++ b/port/msp-exp430f5438-cc2564b/Makefile
@@ -53,7 +53,7 @@ COMMON = \
     hal_uart_dma.c            \
 	bt_control_cc256x.c       \
     hci.c			          \
-    hci_cmds.c		          \
+    hci_cmd.c		          \
     hci_transport_h4_ehcill_embedded.c \
 	remote_device_db_memory.c \
 
diff --git a/port/msp-exp430f5438-cc2564b/example/ant-test.c b/port/msp-exp430f5438-cc2564b/example/ant-test.c
index 7d5745a3c..b02912939 100644
--- a/port/msp-exp430f5438-cc2564b/example/ant-test.c
+++ b/port/msp-exp430f5438-cc2564b/example/ant-test.c
@@ -57,7 +57,7 @@
 #include "hal_usb.h"
 
 #include "ant_cmds.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 #include "btstack_util.h"
diff --git a/port/msp-exp430f5438-cc2564b/example/hid_demo.c b/port/msp-exp430f5438-cc2564b/example/hid_demo.c
index f236330ec..3c5b86428 100644
--- a/port/msp-exp430f5438-cc2564b/example/hid_demo.c
+++ b/port/msp-exp430f5438-cc2564b/example/hid_demo.c
@@ -55,7 +55,7 @@
 #include  <msp430x54x.h>
 
 #include "btstack_run_loop.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_memory.h"
 #include "hci.h"
 #include "l2cap.h"
diff --git a/port/msp-exp430f5438-cc2564b/example/spp_accel.c b/port/msp-exp430f5438-cc2564b/example/spp_accel.c
index 9ab0dc358..73f99ac17 100644
--- a/port/msp-exp430f5438-cc2564b/example/spp_accel.c
+++ b/port/msp-exp430f5438-cc2564b/example/spp_accel.c
@@ -54,7 +54,7 @@
 #include "hal_compat.h"
 #include "hal_usb.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/port/msp430f5229lp-cc2564b/Makefile b/port/msp430f5229lp-cc2564b/Makefile
index b10a7c3b9..2023d7938 100644
--- a/port/msp430f5229lp-cc2564b/Makefile
+++ b/port/msp430f5229lp-cc2564b/Makefile
@@ -55,7 +55,7 @@ COMMON = \
     hal_uart_dma.c            \
 	bt_control_cc256x.c       \
     hci.c			          \
-    hci_cmds.c		          \
+    hci_cmd.c		          \
     hci_transport_h4_ehcill_embedded.c \
 	remote_device_db_memory.c \
 
diff --git a/port/mtk/Makefile b/port/mtk/Makefile
index 05b00048e..877457142 100644
--- a/port/mtk/Makefile
+++ b/port/mtk/Makefile
@@ -29,7 +29,7 @@ libBTstack_OBJS  = 		 \
 	btstack_linked_list.o   \
 	btstack_run_loop.o      \
 	btstack_run_loop_posix.ho     \
-	hci_cmds.o           \
+	hci_cmd.o           \
 	hci_dump.o           \
 	sdp_util.o           \
 	socket_connection.o  \
diff --git a/port/pic32-harmony/app.X/nbproject/Makefile-default.mk b/port/pic32-harmony/app.X/nbproject/Makefile-default.mk
index 0cc876ef8..ef535ff7a 100644
--- a/port/pic32-harmony/app.X/nbproject/Makefile-default.mk
+++ b/port/pic32-harmony/app.X/nbproject/Makefile-default.mk
@@ -45,17 +45,17 @@ OBJECTDIR=build/${CND_CONF}/${IMAGE_TYPE}
 DISTDIR=dist/${CND_CONF}/${IMAGE_TYPE}
 
 # Source Files Quoted if spaced
-SOURCEFILES_QUOTED_IF_SPACED=../src/system_config/bk-audio-dk/system_init.c ../src/system_config/bk-audio-dk/system_tasks.c ../src/btstack_port.c ../src/app_debug.c ../src/app.c ../src/main.c ../../../src/bnep.c ../../../src/btstack_memory.c ../../../src/hci.c ../../../src/hci_cmds.c ../../../src/hci_dump.c ../../../src/hci_transport_h4_embedded.c ../../../src/l2cap.c ../../../src/l2cap_signaling.c ../../../src/linked_list.c ../../../src/btstack_memory_pool.c ../../../src/pan.c ../../../src/remote_device_db_memory.c ../../../src/rfcomm.c ../../../src/btstack_run_loop.c ../../../src/btstack_run_loop_embedded.c ../../../src/sdp.c ../../../src/sdp_client.c ../../../src/sdp_parser.c ../../../src/sdp_query_rfcomm.c ../../../src/sdp_query_util.c ../../../src/sdp_util.c ../../../src/btstack_util.c ../../../../driver/tmr/src/dynamic/drv_tmr.c ../../../../system/clk/src/sys_clk.c ../../../../system/clk/src/sys_clk_pic32mx.c ../../../../system/devcon/src/sys_devcon.c ../../../../system/devcon/src/sys_devcon_pic32mx.c ../../../../system/int/src/sys_int_pic32.c ../../../../system/ports/src/sys_ports.c ../../../chipset/csr/bt_control_csr.c ../../../ble/ad_parser.c ../../../ble/att.c ../../../ble/att_dispatch.c ../../../ble/att_server.c ../../../ble/le_device_db_memory.c ../../../ble/sm.c ../../../example/embedded/spp_and_le_counter.c
+SOURCEFILES_QUOTED_IF_SPACED=../src/system_config/bk-audio-dk/system_init.c ../src/system_config/bk-audio-dk/system_tasks.c ../src/btstack_port.c ../src/app_debug.c ../src/app.c ../src/main.c ../../../src/bnep.c ../../../src/btstack_memory.c ../../../src/hci.c ../../../src/hci_cmd.c ../../../src/hci_dump.c ../../../src/hci_transport_h4_embedded.c ../../../src/l2cap.c ../../../src/l2cap_signaling.c ../../../src/linked_list.c ../../../src/btstack_memory_pool.c ../../../src/pan.c ../../../src/remote_device_db_memory.c ../../../src/rfcomm.c ../../../src/btstack_run_loop.c ../../../src/btstack_run_loop_embedded.c ../../../src/sdp.c ../../../src/sdp_client.c ../../../src/sdp_parser.c ../../../src/sdp_query_rfcomm.c ../../../src/sdp_query_util.c ../../../src/sdp_util.c ../../../src/btstack_util.c ../../../../driver/tmr/src/dynamic/drv_tmr.c ../../../../system/clk/src/sys_clk.c ../../../../system/clk/src/sys_clk_pic32mx.c ../../../../system/devcon/src/sys_devcon.c ../../../../system/devcon/src/sys_devcon_pic32mx.c ../../../../system/int/src/sys_int_pic32.c ../../../../system/ports/src/sys_ports.c ../../../chipset/csr/bt_control_csr.c ../../../ble/ad_parser.c ../../../ble/att.c ../../../ble/att_dispatch.c ../../../ble/att_server.c ../../../ble/le_device_db_memory.c ../../../ble/sm.c ../../../example/embedded/spp_and_le_counter.c
 
 # Object Files Quoted if spaced
-OBJECTFILES_QUOTED_IF_SPACED=${OBJECTDIR}/_ext/2048875307/system_init.o ${OBJECTDIR}/_ext/2048875307/system_tasks.o ${OBJECTDIR}/_ext/1360937237/btstack_port.o ${OBJECTDIR}/_ext/1360937237/app_debug.o ${OBJECTDIR}/_ext/1360937237/app.o ${OBJECTDIR}/_ext/1360937237/main.o ${OBJECTDIR}/_ext/1386528437/bnep.o ${OBJECTDIR}/_ext/1386528437/btstack_memory.o ${OBJECTDIR}/_ext/1386528437/hci.o ${OBJECTDIR}/_ext/1386528437/hci_cmds.o ${OBJECTDIR}/_ext/1386528437/hci_dump.o ${OBJECTDIR}/_ext/1386528437/hci_transport_h4_dma.o ${OBJECTDIR}/_ext/1386528437/l2cap.o ${OBJECTDIR}/_ext/1386528437/l2cap_signaling.o ${OBJECTDIR}/_ext/1386528437/linked_list.o ${OBJECTDIR}/_ext/1386528437/memory_pool.o ${OBJECTDIR}/_ext/1386528437/pan.o ${OBJECTDIR}/_ext/1386528437/remote_device_db_memory.o ${OBJECTDIR}/_ext/1386528437/rfcomm.o ${OBJECTDIR}/_ext/1386528437/run_loop.o ${OBJECTDIR}/_ext/1386528437/btstack_run_loop_embedded.o ${OBJECTDIR}/_ext/1386528437/sdp.o ${OBJECTDIR}/_ext/1386528437/sdp_client.o ${OBJECTDIR}/_ext/1386528437/sdp_parser.o ${OBJECTDIR}/_ext/1386528437/sdp_query_rfcomm.o ${OBJECTDIR}/_ext/1386528437/sdp_query_util.o ${OBJECTDIR}/_ext/1386528437/sdp_util.o ${OBJECTDIR}/_ext/1386528437/utils.o ${OBJECTDIR}/_ext/1880736137/drv_tmr.o ${OBJECTDIR}/_ext/1112166103/sys_clk.o ${OBJECTDIR}/_ext/1112166103/sys_clk_pic32mx.o ${OBJECTDIR}/_ext/1510368962/sys_devcon.o ${OBJECTDIR}/_ext/1510368962/sys_devcon_pic32mx.o ${OBJECTDIR}/_ext/2087176412/sys_int_pic32.o ${OBJECTDIR}/_ext/2147153351/sys_ports.o ${OBJECTDIR}/_ext/1768124388/bt_control_csr.o ${OBJECTDIR}/_ext/1386511916/ad_parser.o ${OBJECTDIR}/_ext/1386511916/att.o ${OBJECTDIR}/_ext/1386511916/att_dispatch.o ${OBJECTDIR}/_ext/1386511916/att_server.o ${OBJECTDIR}/_ext/1386511916/le_device_db_memory.o ${OBJECTDIR}/_ext/1386511916/sm.o ${OBJECTDIR}/_ext/350421922/spp_and_le_counter.o
-POSSIBLE_DEPFILES=${OBJECTDIR}/_ext/2048875307/system_init.o.d ${OBJECTDIR}/_ext/2048875307/system_tasks.o.d ${OBJECTDIR}/_ext/1360937237/btstack_port.o.d ${OBJECTDIR}/_ext/1360937237/app_debug.o.d ${OBJECTDIR}/_ext/1360937237/app.o.d ${OBJECTDIR}/_ext/1360937237/main.o.d ${OBJECTDIR}/_ext/1386528437/bnep.o.d ${OBJECTDIR}/_ext/1386528437/btstack_memory.o.d ${OBJECTDIR}/_ext/1386528437/hci.o.d ${OBJECTDIR}/_ext/1386528437/hci_cmds.o.d ${OBJECTDIR}/_ext/1386528437/hci_dump.o.d ${OBJECTDIR}/_ext/1386528437/hci_transport_h4_dma.o.d ${OBJECTDIR}/_ext/1386528437/l2cap.o.d ${OBJECTDIR}/_ext/1386528437/l2cap_signaling.o.d ${OBJECTDIR}/_ext/1386528437/linked_list.o.d ${OBJECTDIR}/_ext/1386528437/memory_pool.o.d ${OBJECTDIR}/_ext/1386528437/pan.o.d ${OBJECTDIR}/_ext/1386528437/remote_device_db_memory.o.d ${OBJECTDIR}/_ext/1386528437/rfcomm.o.d ${OBJECTDIR}/_ext/1386528437/run_loop.o.d ${OBJECTDIR}/_ext/1386528437/btstack_run_loop_embedded.o.d ${OBJECTDIR}/_ext/1386528437/sdp.o.d ${OBJECTDIR}/_ext/1386528437/sdp_client.o.d ${OBJECTDIR}/_ext/1386528437/sdp_parser.o.d ${OBJECTDIR}/_ext/1386528437/sdp_query_rfcomm.o.d ${OBJECTDIR}/_ext/1386528437/sdp_query_util.o.d ${OBJECTDIR}/_ext/1386528437/sdp_util.o.d ${OBJECTDIR}/_ext/1386528437/utils.o.d ${OBJECTDIR}/_ext/1880736137/drv_tmr.o.d ${OBJECTDIR}/_ext/1112166103/sys_clk.o.d ${OBJECTDIR}/_ext/1112166103/sys_clk_pic32mx.o.d ${OBJECTDIR}/_ext/1510368962/sys_devcon.o.d ${OBJECTDIR}/_ext/1510368962/sys_devcon_pic32mx.o.d ${OBJECTDIR}/_ext/2087176412/sys_int_pic32.o.d ${OBJECTDIR}/_ext/2147153351/sys_ports.o.d ${OBJECTDIR}/_ext/1768124388/bt_control_csr.o.d ${OBJECTDIR}/_ext/1386511916/ad_parser.o.d ${OBJECTDIR}/_ext/1386511916/att.o.d ${OBJECTDIR}/_ext/1386511916/att_dispatch.o.d ${OBJECTDIR}/_ext/1386511916/att_server.o.d ${OBJECTDIR}/_ext/1386511916/le_device_db_memory.o.d ${OBJECTDIR}/_ext/1386511916/sm.o.d ${OBJECTDIR}/_ext/350421922/spp_and_le_counter.o.d
+OBJECTFILES_QUOTED_IF_SPACED=${OBJECTDIR}/_ext/2048875307/system_init.o ${OBJECTDIR}/_ext/2048875307/system_tasks.o ${OBJECTDIR}/_ext/1360937237/btstack_port.o ${OBJECTDIR}/_ext/1360937237/app_debug.o ${OBJECTDIR}/_ext/1360937237/app.o ${OBJECTDIR}/_ext/1360937237/main.o ${OBJECTDIR}/_ext/1386528437/bnep.o ${OBJECTDIR}/_ext/1386528437/btstack_memory.o ${OBJECTDIR}/_ext/1386528437/hci.o ${OBJECTDIR}/_ext/1386528437/hci_cmd.o ${OBJECTDIR}/_ext/1386528437/hci_dump.o ${OBJECTDIR}/_ext/1386528437/hci_transport_h4_dma.o ${OBJECTDIR}/_ext/1386528437/l2cap.o ${OBJECTDIR}/_ext/1386528437/l2cap_signaling.o ${OBJECTDIR}/_ext/1386528437/linked_list.o ${OBJECTDIR}/_ext/1386528437/memory_pool.o ${OBJECTDIR}/_ext/1386528437/pan.o ${OBJECTDIR}/_ext/1386528437/remote_device_db_memory.o ${OBJECTDIR}/_ext/1386528437/rfcomm.o ${OBJECTDIR}/_ext/1386528437/run_loop.o ${OBJECTDIR}/_ext/1386528437/btstack_run_loop_embedded.o ${OBJECTDIR}/_ext/1386528437/sdp.o ${OBJECTDIR}/_ext/1386528437/sdp_client.o ${OBJECTDIR}/_ext/1386528437/sdp_parser.o ${OBJECTDIR}/_ext/1386528437/sdp_query_rfcomm.o ${OBJECTDIR}/_ext/1386528437/sdp_query_util.o ${OBJECTDIR}/_ext/1386528437/sdp_util.o ${OBJECTDIR}/_ext/1386528437/utils.o ${OBJECTDIR}/_ext/1880736137/drv_tmr.o ${OBJECTDIR}/_ext/1112166103/sys_clk.o ${OBJECTDIR}/_ext/1112166103/sys_clk_pic32mx.o ${OBJECTDIR}/_ext/1510368962/sys_devcon.o ${OBJECTDIR}/_ext/1510368962/sys_devcon_pic32mx.o ${OBJECTDIR}/_ext/2087176412/sys_int_pic32.o ${OBJECTDIR}/_ext/2147153351/sys_ports.o ${OBJECTDIR}/_ext/1768124388/bt_control_csr.o ${OBJECTDIR}/_ext/1386511916/ad_parser.o ${OBJECTDIR}/_ext/1386511916/att.o ${OBJECTDIR}/_ext/1386511916/att_dispatch.o ${OBJECTDIR}/_ext/1386511916/att_server.o ${OBJECTDIR}/_ext/1386511916/le_device_db_memory.o ${OBJECTDIR}/_ext/1386511916/sm.o ${OBJECTDIR}/_ext/350421922/spp_and_le_counter.o
+POSSIBLE_DEPFILES=${OBJECTDIR}/_ext/2048875307/system_init.o.d ${OBJECTDIR}/_ext/2048875307/system_tasks.o.d ${OBJECTDIR}/_ext/1360937237/btstack_port.o.d ${OBJECTDIR}/_ext/1360937237/app_debug.o.d ${OBJECTDIR}/_ext/1360937237/app.o.d ${OBJECTDIR}/_ext/1360937237/main.o.d ${OBJECTDIR}/_ext/1386528437/bnep.o.d ${OBJECTDIR}/_ext/1386528437/btstack_memory.o.d ${OBJECTDIR}/_ext/1386528437/hci.o.d ${OBJECTDIR}/_ext/1386528437/hci_cmd.o.d ${OBJECTDIR}/_ext/1386528437/hci_dump.o.d ${OBJECTDIR}/_ext/1386528437/hci_transport_h4_dma.o.d ${OBJECTDIR}/_ext/1386528437/l2cap.o.d ${OBJECTDIR}/_ext/1386528437/l2cap_signaling.o.d ${OBJECTDIR}/_ext/1386528437/linked_list.o.d ${OBJECTDIR}/_ext/1386528437/memory_pool.o.d ${OBJECTDIR}/_ext/1386528437/pan.o.d ${OBJECTDIR}/_ext/1386528437/remote_device_db_memory.o.d ${OBJECTDIR}/_ext/1386528437/rfcomm.o.d ${OBJECTDIR}/_ext/1386528437/run_loop.o.d ${OBJECTDIR}/_ext/1386528437/btstack_run_loop_embedded.o.d ${OBJECTDIR}/_ext/1386528437/sdp.o.d ${OBJECTDIR}/_ext/1386528437/sdp_client.o.d ${OBJECTDIR}/_ext/1386528437/sdp_parser.o.d ${OBJECTDIR}/_ext/1386528437/sdp_query_rfcomm.o.d ${OBJECTDIR}/_ext/1386528437/sdp_query_util.o.d ${OBJECTDIR}/_ext/1386528437/sdp_util.o.d ${OBJECTDIR}/_ext/1386528437/utils.o.d ${OBJECTDIR}/_ext/1880736137/drv_tmr.o.d ${OBJECTDIR}/_ext/1112166103/sys_clk.o.d ${OBJECTDIR}/_ext/1112166103/sys_clk_pic32mx.o.d ${OBJECTDIR}/_ext/1510368962/sys_devcon.o.d ${OBJECTDIR}/_ext/1510368962/sys_devcon_pic32mx.o.d ${OBJECTDIR}/_ext/2087176412/sys_int_pic32.o.d ${OBJECTDIR}/_ext/2147153351/sys_ports.o.d ${OBJECTDIR}/_ext/1768124388/bt_control_csr.o.d ${OBJECTDIR}/_ext/1386511916/ad_parser.o.d ${OBJECTDIR}/_ext/1386511916/att.o.d ${OBJECTDIR}/_ext/1386511916/att_dispatch.o.d ${OBJECTDIR}/_ext/1386511916/att_server.o.d ${OBJECTDIR}/_ext/1386511916/le_device_db_memory.o.d ${OBJECTDIR}/_ext/1386511916/sm.o.d ${OBJECTDIR}/_ext/350421922/spp_and_le_counter.o.d
 
 # Object Files
-OBJECTFILES=${OBJECTDIR}/_ext/2048875307/system_init.o ${OBJECTDIR}/_ext/2048875307/system_tasks.o ${OBJECTDIR}/_ext/1360937237/btstack_port.o ${OBJECTDIR}/_ext/1360937237/app_debug.o ${OBJECTDIR}/_ext/1360937237/app.o ${OBJECTDIR}/_ext/1360937237/main.o ${OBJECTDIR}/_ext/1386528437/bnep.o ${OBJECTDIR}/_ext/1386528437/btstack_memory.o ${OBJECTDIR}/_ext/1386528437/hci.o ${OBJECTDIR}/_ext/1386528437/hci_cmds.o ${OBJECTDIR}/_ext/1386528437/hci_dump.o ${OBJECTDIR}/_ext/1386528437/hci_transport_h4_dma.o ${OBJECTDIR}/_ext/1386528437/l2cap.o ${OBJECTDIR}/_ext/1386528437/l2cap_signaling.o ${OBJECTDIR}/_ext/1386528437/linked_list.o ${OBJECTDIR}/_ext/1386528437/memory_pool.o ${OBJECTDIR}/_ext/1386528437/pan.o ${OBJECTDIR}/_ext/1386528437/remote_device_db_memory.o ${OBJECTDIR}/_ext/1386528437/rfcomm.o ${OBJECTDIR}/_ext/1386528437/run_loop.o ${OBJECTDIR}/_ext/1386528437/btstack_run_loop_embedded.o ${OBJECTDIR}/_ext/1386528437/sdp.o ${OBJECTDIR}/_ext/1386528437/sdp_client.o ${OBJECTDIR}/_ext/1386528437/sdp_parser.o ${OBJECTDIR}/_ext/1386528437/sdp_query_rfcomm.o ${OBJECTDIR}/_ext/1386528437/sdp_query_util.o ${OBJECTDIR}/_ext/1386528437/sdp_util.o ${OBJECTDIR}/_ext/1386528437/utils.o ${OBJECTDIR}/_ext/1880736137/drv_tmr.o ${OBJECTDIR}/_ext/1112166103/sys_clk.o ${OBJECTDIR}/_ext/1112166103/sys_clk_pic32mx.o ${OBJECTDIR}/_ext/1510368962/sys_devcon.o ${OBJECTDIR}/_ext/1510368962/sys_devcon_pic32mx.o ${OBJECTDIR}/_ext/2087176412/sys_int_pic32.o ${OBJECTDIR}/_ext/2147153351/sys_ports.o ${OBJECTDIR}/_ext/1768124388/bt_control_csr.o ${OBJECTDIR}/_ext/1386511916/ad_parser.o ${OBJECTDIR}/_ext/1386511916/att.o ${OBJECTDIR}/_ext/1386511916/att_dispatch.o ${OBJECTDIR}/_ext/1386511916/att_server.o ${OBJECTDIR}/_ext/1386511916/le_device_db_memory.o ${OBJECTDIR}/_ext/1386511916/sm.o ${OBJECTDIR}/_ext/350421922/spp_and_le_counter.o
+OBJECTFILES=${OBJECTDIR}/_ext/2048875307/system_init.o ${OBJECTDIR}/_ext/2048875307/system_tasks.o ${OBJECTDIR}/_ext/1360937237/btstack_port.o ${OBJECTDIR}/_ext/1360937237/app_debug.o ${OBJECTDIR}/_ext/1360937237/app.o ${OBJECTDIR}/_ext/1360937237/main.o ${OBJECTDIR}/_ext/1386528437/bnep.o ${OBJECTDIR}/_ext/1386528437/btstack_memory.o ${OBJECTDIR}/_ext/1386528437/hci.o ${OBJECTDIR}/_ext/1386528437/hci_cmd.o ${OBJECTDIR}/_ext/1386528437/hci_dump.o ${OBJECTDIR}/_ext/1386528437/hci_transport_h4_dma.o ${OBJECTDIR}/_ext/1386528437/l2cap.o ${OBJECTDIR}/_ext/1386528437/l2cap_signaling.o ${OBJECTDIR}/_ext/1386528437/linked_list.o ${OBJECTDIR}/_ext/1386528437/memory_pool.o ${OBJECTDIR}/_ext/1386528437/pan.o ${OBJECTDIR}/_ext/1386528437/remote_device_db_memory.o ${OBJECTDIR}/_ext/1386528437/rfcomm.o ${OBJECTDIR}/_ext/1386528437/run_loop.o ${OBJECTDIR}/_ext/1386528437/btstack_run_loop_embedded.o ${OBJECTDIR}/_ext/1386528437/sdp.o ${OBJECTDIR}/_ext/1386528437/sdp_client.o ${OBJECTDIR}/_ext/1386528437/sdp_parser.o ${OBJECTDIR}/_ext/1386528437/sdp_query_rfcomm.o ${OBJECTDIR}/_ext/1386528437/sdp_query_util.o ${OBJECTDIR}/_ext/1386528437/sdp_util.o ${OBJECTDIR}/_ext/1386528437/utils.o ${OBJECTDIR}/_ext/1880736137/drv_tmr.o ${OBJECTDIR}/_ext/1112166103/sys_clk.o ${OBJECTDIR}/_ext/1112166103/sys_clk_pic32mx.o ${OBJECTDIR}/_ext/1510368962/sys_devcon.o ${OBJECTDIR}/_ext/1510368962/sys_devcon_pic32mx.o ${OBJECTDIR}/_ext/2087176412/sys_int_pic32.o ${OBJECTDIR}/_ext/2147153351/sys_ports.o ${OBJECTDIR}/_ext/1768124388/bt_control_csr.o ${OBJECTDIR}/_ext/1386511916/ad_parser.o ${OBJECTDIR}/_ext/1386511916/att.o ${OBJECTDIR}/_ext/1386511916/att_dispatch.o ${OBJECTDIR}/_ext/1386511916/att_server.o ${OBJECTDIR}/_ext/1386511916/le_device_db_memory.o ${OBJECTDIR}/_ext/1386511916/sm.o ${OBJECTDIR}/_ext/350421922/spp_and_le_counter.o
 
 # Source Files
-SOURCEFILES=../src/system_config/bk-audio-dk/system_init.c ../src/system_config/bk-audio-dk/system_tasks.c ../src/btstack_port.c ../src/app_debug.c ../src/app.c ../src/main.c ../../../src/bnep.c ../../../src/btstack_memory.c ../../../src/hci.c ../../../src/hci_cmds.c ../../../src/hci_dump.c ../../../src/hci_transport_h4_embedded.c ../../../src/l2cap.c ../../../src/l2cap_signaling.c ../../../src/linked_list.c ../../../src/btstack_memory_pool.c ../../../src/pan.c ../../../src/remote_device_db_memory.c ../../../src/rfcomm.c ../../../src/btstack_run_loop.c ../../../src/btstack_run_loop_embedded.c ../../../src/sdp.c ../../../src/sdp_client.c ../../../src/sdp_parser.c ../../../src/sdp_query_rfcomm.c ../../../src/sdp_query_util.c ../../../src/sdp_util.c ../../../src/btstack_util.c ../../../../driver/tmr/src/dynamic/drv_tmr.c ../../../../system/clk/src/sys_clk.c ../../../../system/clk/src/sys_clk_pic32mx.c ../../../../system/devcon/src/sys_devcon.c ../../../../system/devcon/src/sys_devcon_pic32mx.c ../../../../system/int/src/sys_int_pic32.c ../../../../system/ports/src/sys_ports.c ../../../chipset/csr/bt_control_csr.c ../../../ble/ad_parser.c ../../../ble/att.c ../../../ble/att_dispatch.c ../../../ble/att_server.c ../../../ble/le_device_db_memory.c ../../../ble/sm.c ../../../example/embedded/spp_and_le_counter.c
+SOURCEFILES=../src/system_config/bk-audio-dk/system_init.c ../src/system_config/bk-audio-dk/system_tasks.c ../src/btstack_port.c ../src/app_debug.c ../src/app.c ../src/main.c ../../../src/bnep.c ../../../src/btstack_memory.c ../../../src/hci.c ../../../src/hci_cmd.c ../../../src/hci_dump.c ../../../src/hci_transport_h4_embedded.c ../../../src/l2cap.c ../../../src/l2cap_signaling.c ../../../src/linked_list.c ../../../src/btstack_memory_pool.c ../../../src/pan.c ../../../src/remote_device_db_memory.c ../../../src/rfcomm.c ../../../src/btstack_run_loop.c ../../../src/btstack_run_loop_embedded.c ../../../src/sdp.c ../../../src/sdp_client.c ../../../src/sdp_parser.c ../../../src/sdp_query_rfcomm.c ../../../src/sdp_query_util.c ../../../src/sdp_util.c ../../../src/btstack_util.c ../../../../driver/tmr/src/dynamic/drv_tmr.c ../../../../system/clk/src/sys_clk.c ../../../../system/clk/src/sys_clk_pic32mx.c ../../../../system/devcon/src/sys_devcon.c ../../../../system/devcon/src/sys_devcon_pic32mx.c ../../../../system/int/src/sys_int_pic32.c ../../../../system/ports/src/sys_ports.c ../../../chipset/csr/bt_control_csr.c ../../../ble/ad_parser.c ../../../ble/att.c ../../../ble/att_dispatch.c ../../../ble/att_server.c ../../../ble/le_device_db_memory.c ../../../ble/sm.c ../../../example/embedded/spp_and_le_counter.c
 
 
 CFLAGS=
@@ -148,11 +148,11 @@ ${OBJECTDIR}/_ext/1386528437/hci.o: ../../../src/hci.c  nbproject/Makefile-${CND
 	@${RM} ${OBJECTDIR}/_ext/1386528437/hci.o 
 	@${FIXDEPS} "${OBJECTDIR}/_ext/1386528437/hci.o.d" $(SILENT) -rsi ${MP_CC_DIR}../  -c ${MP_CC}  $(MP_EXTRA_CC_PRE) -g -D__DEBUG -D__MPLAB_DEBUGGER_PK3=1 -fframe-base-loclist  -x c -c -mprocessor=$(MP_PROCESSOR_OPTION)  -Os -I"." -I"../../../.." -I"../src" -I"../src/system_config/bk-audio-dk" -I"../../../include" -I"../../../src" -I"../../../ble" -I"../../../chipset/csr" -MMD -MF "${OBJECTDIR}/_ext/1386528437/hci.o.d" -o ${OBJECTDIR}/_ext/1386528437/hci.o ../../../src/hci.c   
 	
-${OBJECTDIR}/_ext/1386528437/hci_cmds.o: ../../../src/hci_cmds.c  nbproject/Makefile-${CND_CONF}.mk
+${OBJECTDIR}/_ext/1386528437/hci_cmd.o: ../../../src/hci_cmd.c  nbproject/Makefile-${CND_CONF}.mk
 	@${MKDIR} "${OBJECTDIR}/_ext/1386528437" 
-	@${RM} ${OBJECTDIR}/_ext/1386528437/hci_cmds.o.d 
-	@${RM} ${OBJECTDIR}/_ext/1386528437/hci_cmds.o 
-	@${FIXDEPS} "${OBJECTDIR}/_ext/1386528437/hci_cmds.o.d" $(SILENT) -rsi ${MP_CC_DIR}../  -c ${MP_CC}  $(MP_EXTRA_CC_PRE) -g -D__DEBUG -D__MPLAB_DEBUGGER_PK3=1 -fframe-base-loclist  -x c -c -mprocessor=$(MP_PROCESSOR_OPTION)  -Os -I"." -I"../../../.." -I"../src" -I"../src/system_config/bk-audio-dk" -I"../../../include" -I"../../../src" -I"../../../ble" -I"../../../chipset/csr" -MMD -MF "${OBJECTDIR}/_ext/1386528437/hci_cmds.o.d" -o ${OBJECTDIR}/_ext/1386528437/hci_cmds.o ../../../src/hci_cmds.c   
+	@${RM} ${OBJECTDIR}/_ext/1386528437/hci_cmd.o.d 
+	@${RM} ${OBJECTDIR}/_ext/1386528437/hci_cmd.o 
+	@${FIXDEPS} "${OBJECTDIR}/_ext/1386528437/hci_cmd.o.d" $(SILENT) -rsi ${MP_CC_DIR}../  -c ${MP_CC}  $(MP_EXTRA_CC_PRE) -g -D__DEBUG -D__MPLAB_DEBUGGER_PK3=1 -fframe-base-loclist  -x c -c -mprocessor=$(MP_PROCESSOR_OPTION)  -Os -I"." -I"../../../.." -I"../src" -I"../src/system_config/bk-audio-dk" -I"../../../include" -I"../../../src" -I"../../../ble" -I"../../../chipset/csr" -MMD -MF "${OBJECTDIR}/_ext/1386528437/hci_cmd.o.d" -o ${OBJECTDIR}/_ext/1386528437/hci_cmd.o ../../../src/hci_cmd.c   
 	
 ${OBJECTDIR}/_ext/1386528437/hci_dump.o: ../../../src/hci_dump.c  nbproject/Makefile-${CND_CONF}.mk
 	@${MKDIR} "${OBJECTDIR}/_ext/1386528437" 
@@ -407,11 +407,11 @@ ${OBJECTDIR}/_ext/1386528437/hci.o: ../../../src/hci.c  nbproject/Makefile-${CND
 	@${RM} ${OBJECTDIR}/_ext/1386528437/hci.o 
 	@${FIXDEPS} "${OBJECTDIR}/_ext/1386528437/hci.o.d" $(SILENT) -rsi ${MP_CC_DIR}../  -c ${MP_CC}  $(MP_EXTRA_CC_PRE)  -g -x c -c -mprocessor=$(MP_PROCESSOR_OPTION)  -Os -I"." -I"../../../.." -I"../src" -I"../src/system_config/bk-audio-dk" -I"../../../include" -I"../../../src" -I"../../../ble" -I"../../../chipset/csr" -MMD -MF "${OBJECTDIR}/_ext/1386528437/hci.o.d" -o ${OBJECTDIR}/_ext/1386528437/hci.o ../../../src/hci.c   
 	
-${OBJECTDIR}/_ext/1386528437/hci_cmds.o: ../../../src/hci_cmds.c  nbproject/Makefile-${CND_CONF}.mk
+${OBJECTDIR}/_ext/1386528437/hci_cmd.o: ../../../src/hci_cmd.c  nbproject/Makefile-${CND_CONF}.mk
 	@${MKDIR} "${OBJECTDIR}/_ext/1386528437" 
-	@${RM} ${OBJECTDIR}/_ext/1386528437/hci_cmds.o.d 
-	@${RM} ${OBJECTDIR}/_ext/1386528437/hci_cmds.o 
-	@${FIXDEPS} "${OBJECTDIR}/_ext/1386528437/hci_cmds.o.d" $(SILENT) -rsi ${MP_CC_DIR}../  -c ${MP_CC}  $(MP_EXTRA_CC_PRE)  -g -x c -c -mprocessor=$(MP_PROCESSOR_OPTION)  -Os -I"." -I"../../../.." -I"../src" -I"../src/system_config/bk-audio-dk" -I"../../../include" -I"../../../src" -I"../../../ble" -I"../../../chipset/csr" -MMD -MF "${OBJECTDIR}/_ext/1386528437/hci_cmds.o.d" -o ${OBJECTDIR}/_ext/1386528437/hci_cmds.o ../../../src/hci_cmds.c   
+	@${RM} ${OBJECTDIR}/_ext/1386528437/hci_cmd.o.d 
+	@${RM} ${OBJECTDIR}/_ext/1386528437/hci_cmd.o 
+	@${FIXDEPS} "${OBJECTDIR}/_ext/1386528437/hci_cmd.o.d" $(SILENT) -rsi ${MP_CC_DIR}../  -c ${MP_CC}  $(MP_EXTRA_CC_PRE)  -g -x c -c -mprocessor=$(MP_PROCESSOR_OPTION)  -Os -I"." -I"../../../.." -I"../src" -I"../src/system_config/bk-audio-dk" -I"../../../include" -I"../../../src" -I"../../../ble" -I"../../../chipset/csr" -MMD -MF "${OBJECTDIR}/_ext/1386528437/hci_cmd.o.d" -o ${OBJECTDIR}/_ext/1386528437/hci_cmd.o ../../../src/hci_cmd.c   
 	
 ${OBJECTDIR}/_ext/1386528437/hci_dump.o: ../../../src/hci_dump.c  nbproject/Makefile-${CND_CONF}.mk
 	@${MKDIR} "${OBJECTDIR}/_ext/1386528437" 
diff --git a/port/pic32-harmony/app.X/nbproject/configurations.xml b/port/pic32-harmony/app.X/nbproject/configurations.xml
index 4f5e6c383..eceb69369 100644
--- a/port/pic32-harmony/app.X/nbproject/configurations.xml
+++ b/port/pic32-harmony/app.X/nbproject/configurations.xml
@@ -34,7 +34,7 @@
           <itemPath>../../../platform/embedded/hal_uart_dma.h</itemPath>
         </logicalFolder>
         <logicalFolder name="src" displayName="src" projectFiles="true">
-          <itemPath>../../../src/hci_cmds.h</itemPath>
+          <itemPath>../../../src/hci_cmd.h</itemPath>
           <itemPath>../../../src/btstack_linked_list.h</itemPath>
           <itemPath>../../../src/btstack_memory_pool.h</itemPath>
           <itemPath>../../../src/run_loop.h</itemPath>
@@ -122,7 +122,7 @@
         <logicalFolder name="src" displayName="src" projectFiles="true">
           <itemPath>../../../src/btstack_memory.c</itemPath>
           <itemPath>../../../src/hci.c</itemPath>
-          <itemPath>../../../src/hci_cmds.c</itemPath>
+          <itemPath>../../../src/hci_cmd.c</itemPath>
           <itemPath>../../../src/hci_dump.c</itemPath>
           <itemPath>../../../src/hci_transport_h4_embedded.c</itemPath>
           <itemPath>../../../src/l2cap.c</itemPath>
diff --git a/port/stm32-f103rb-nucleo/Makefile b/port/stm32-f103rb-nucleo/Makefile
index bb5f5c7c8..e9ff6f0ad 100644
--- a/port/stm32-f103rb-nucleo/Makefile
+++ b/port/stm32-f103rb-nucleo/Makefile
@@ -27,7 +27,7 @@ COMMON = \
 	bt_control_cc256x.c   \
 	bluetooth_init_cc2564B_1.2_BT_Spec_4.1.c   \
     hci.c			          \
-    hci_cmds.c		          \
+    hci_cmd.c		          \
     hci_dump.c		          \
     hci_transport_h4_ehcill_embedded.c \
     l2cap.c			          \
diff --git a/port/wiced/wiced.mk b/port/wiced/wiced.mk
index 0df5321f0..a89f50c53 100644
--- a/port/wiced/wiced.mk
+++ b/port/wiced/wiced.mk
@@ -29,7 +29,7 @@ $(NAME)_SOURCES += \
 	../../src/classic/sdp_query_util.c    \
 	../../src/classic/sdp_util.c          \
 	../../src/hci.c                       \
-	../../src/hci_cmds.c                  \
+	../../src/hci_cmd.c                  \
 	../../src/hci_dump.c                  \
 	../../src/l2cap.c                     \
 	../../src/l2cap_signaling.c           \
diff --git a/src/ble/ad_parser.c b/src/ble/ad_parser.c
index 1336e3f8b..f0a8ccb3f 100644
--- a/src/ble/ad_parser.c
+++ b/src/ble/ad_parser.c
@@ -49,7 +49,7 @@
 
 #include "btstack_util.h"
 #include "classic/sdp_util.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #include "hci.h"
 #include "ble/ad_parser.h"
diff --git a/src/ble/gatt_client.c b/src/ble/gatt_client.c
index 388994d06..c5343624f 100644
--- a/src/ble/gatt_client.c
+++ b/src/ble/gatt_client.c
@@ -40,7 +40,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "btstack_run_loop.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_util.h"
 #include "classic/sdp_util.h"
 
diff --git a/src/btstack.h b/src/btstack.h
index e99c45215..5ca3f3631 100644
--- a/src/btstack.h
+++ b/src/btstack.h
@@ -59,7 +59,7 @@
 #include "btstack_version.h"
 #include "gap.h"
 #include "hci.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "hci_dump.h"
 #include "hci_transport.h"
 #include "l2cap.h"
diff --git a/src/classic/bnep.c b/src/classic/bnep.c
index 30601f5bf..57f122fc5 100644
--- a/src/classic/bnep.c
+++ b/src/classic/bnep.c
@@ -46,7 +46,7 @@
 #include <string.h> // memcpy
 #include <stdint.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_util.h"
 #include "classic/sdp_util.h"
 
diff --git a/src/classic/hfp.c b/src/classic/hfp.c
index 35eae3480..55f98dd5b 100644
--- a/src/classic/hfp.c
+++ b/src/classic/hfp.c
@@ -49,7 +49,7 @@
 #include <string.h>
 #include <inttypes.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/src/classic/hfp_ag.c b/src/classic/hfp_ag.c
index 53603dbe8..88b6ec108 100644
--- a/src/classic/hfp_ag.c
+++ b/src/classic/hfp_ag.c
@@ -48,7 +48,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/src/classic/hfp_gsm_model.c b/src/classic/hfp_gsm_model.c
index cd5bcd0ad..37605c5f6 100644
--- a/src/classic/hfp_gsm_model.c
+++ b/src/classic/hfp_gsm_model.c
@@ -55,7 +55,7 @@
 #include "classic/sdp_query_rfcomm.h"
 #include "btstack_debug.h"
 #include "hci.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "hci_dump.h"
 #include "l2cap.h"
 #include "btstack_run_loop.h"
diff --git a/src/classic/hfp_hf.c b/src/classic/hfp_hf.c
index 437eb5de3..72894e0e1 100644
--- a/src/classic/hfp_hf.c
+++ b/src/classic/hfp_hf.c
@@ -48,7 +48,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/src/classic/hsp_ag.c b/src/classic/hsp_ag.c
index 5042f190d..9fca0b7ad 100644
--- a/src/classic/hsp_ag.c
+++ b/src/classic/hsp_ag.c
@@ -48,7 +48,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/src/classic/hsp_hs.c b/src/classic/hsp_hs.c
index 5833a326e..a1c57e3a1 100644
--- a/src/classic/hsp_hs.c
+++ b/src/classic/hsp_hs.c
@@ -48,7 +48,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/src/classic/pan.c b/src/classic/pan.c
index 361ef6e9b..9f320f876 100644
--- a/src/classic/pan.c
+++ b/src/classic/pan.c
@@ -49,7 +49,7 @@
 #include "btstack-config.h"
 
 #include "classic/sdp_util.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 static const char default_panu_service_name[] = "Personal Ad-hoc User Service";
 static const char default_panu_service_desc[] = "Personal Ad-hoc User Service";
diff --git a/src/classic/rfcomm.c b/src/classic/rfcomm.c
index b65ec4ccc..71027f4e5 100644
--- a/src/classic/rfcomm.c
+++ b/src/classic/rfcomm.c
@@ -44,7 +44,7 @@
 #include <string.h> // memcpy
 #include <stdint.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_util.h"
 
 #include "btstack_util.h"
diff --git a/src/classic/sdp_client.c b/src/classic/sdp_client.c
index d530c28f0..f4604ee03 100644
--- a/src/classic/sdp_client.c
+++ b/src/classic/sdp_client.c
@@ -42,7 +42,7 @@
 #include "btstack-config.h"
 #include "classic/sdp_client.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #include "l2cap.h"
 #include "classic/sdp_parser.h"
diff --git a/src/classic/sdp_parser.c b/src/classic/sdp_parser.c
index 5153c97e6..247472b83 100644
--- a/src/classic/sdp_parser.c
+++ b/src/classic/sdp_parser.c
@@ -38,7 +38,7 @@
 /*
  *  sdp_parser.c
  */
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "classic/sdp_parser.h"
 #include "btstack_debug.h"
 
diff --git a/src/classic/sdp_query_rfcomm.c b/src/classic/sdp_query_rfcomm.c
index 8fe88961b..8ea66d511 100644
--- a/src/classic/sdp_query_rfcomm.c
+++ b/src/classic/sdp_query_rfcomm.c
@@ -44,7 +44,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "classic/sdp_util.h"
 
 #include "classic/sdp_client.h"
diff --git a/src/hci.c b/src/hci.c
index e032b5ff6..f8e13e815 100644
--- a/src/hci.c
+++ b/src/hci.c
@@ -74,7 +74,7 @@
 #include "hci_dump.h"
 
 #include "btstack_linked_list.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #define HCI_CONNECTION_TIMEOUT_MS 10000
 
diff --git a/src/hci.h b/src/hci.h
index 3392d5dcb..9f8532598 100644
--- a/src/hci.h
+++ b/src/hci.h
@@ -50,7 +50,7 @@
 
 #include "btstack_control.h"
 #include "classic/remote_device_db.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "hci_transport.h"
 #include "btstack_linked_list.h"
 #include "btstack_util.h"
diff --git a/src/hci_cmds.c b/src/hci_cmd.c
similarity index 99%
rename from src/hci_cmds.c
rename to src/hci_cmd.c
index 14105c7f1..b17f6d112 100644
--- a/src/hci_cmds.c
+++ b/src/hci_cmd.c
@@ -36,7 +36,7 @@
  */
 
 /*
- *  hci_cmds.c
+ *  hci_cmd.c
  *
  *  Created by Matthias Ringwald on 7/23/09.
  */
@@ -45,7 +45,7 @@
 
 #include "classic/sdp_util.h"
 #include "hci.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #include <string.h>
 
diff --git a/src/hci_cmds.h b/src/hci_cmd.h
similarity index 99%
rename from src/hci_cmds.h
rename to src/hci_cmd.h
index a4bbeb252..16eda89d2 100644
--- a/src/hci_cmds.h
+++ b/src/hci_cmd.h
@@ -36,7 +36,7 @@
  */
 
 /*
- *  hci_cmds.h
+ *  hci_cmd.h
  *
  *  Created by Matthias Ringwald on 7/23/09.
  */
@@ -84,7 +84,7 @@ typedef enum {
 } hci_cmd_t;
 
 
-// HCI Commands - see hci_cmds.c for info on parameters
+// HCI Commands - see hci_cmd.c for info on parameters
 extern const hci_cmd_t hci_accept_connection_request;
 extern const hci_cmd_t hci_accept_synchronous_connection;
 extern const hci_cmd_t hci_authentication_requested;
diff --git a/src/hci_dump.c b/src/hci_dump.c
index 0e9af145d..b874f9afd 100644
--- a/src/hci_dump.c
+++ b/src/hci_dump.c
@@ -52,7 +52,7 @@
 #include "hci_dump.h"
 #include "hci.h"
 #include "hci_transport.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include <stdio.h>
 
diff --git a/src/l2cap_signaling.h b/src/l2cap_signaling.h
index 81901090c..25125c278 100644
--- a/src/l2cap_signaling.h
+++ b/src/l2cap_signaling.h
@@ -47,7 +47,7 @@
 #include <stdint.h>
 #include <stdarg.h>
 #include "btstack_util.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #if defined __cplusplus
 extern "C" {
diff --git a/test/ble_client/Makefile b/test/ble_client/Makefile
index 413a79d07..212fadfd0 100644
--- a/test/ble_client/Makefile
+++ b/test/ble_client/Makefile
@@ -20,7 +20,7 @@ COMMON = \
     btstack_run_loop_posix.c 	\
     btstack_util.c			    \
     hci.c                       \
-    hci_cmds.c					\
+    hci_cmd.c					\
     hci_dump.c					\
 	
 COMMON_OBJ = $(COMMON:.c=.o)
diff --git a/test/ble_client/advertising_data_parser.c b/test/ble_client/advertising_data_parser.c
index d5a8e7bae..5ae16da41 100644
--- a/test/ble_client/advertising_data_parser.c
+++ b/test/ble_client/advertising_data_parser.c
@@ -50,7 +50,7 @@
 #include "CppUTest/TestHarness.h"
 #include "CppUTest/CommandLineTestRunner.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #include "btstack_memory.h"
 #include "hci.h"
diff --git a/test/gatt_client/Makefile b/test/gatt_client/Makefile
index 06c31d66e..2a133f4c8 100644
--- a/test/gatt_client/Makefile
+++ b/test/gatt_client/Makefile
@@ -18,7 +18,7 @@ COMMON = \
     btstack_linked_list.c		    \
     btstack_memory.c			\
     gatt_client.c               \
-    hci_cmds.c					\
+    hci_cmd.c					\
     hci_dump.c     				\
     le_device_db_memory.c       \
     btstack_memory_pool.c			    \
diff --git a/test/gatt_client/gatt_client_test.c b/test/gatt_client/gatt_client_test.c
index 6d0e39292..f9d0633af 100644
--- a/test/gatt_client/gatt_client_test.c
+++ b/test/gatt_client/gatt_client_test.c
@@ -14,7 +14,7 @@
 #include "CppUTest/TestHarness.h"
 #include "CppUTest/CommandLineTestRunner.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #include "btstack_memory.h"
 #include "hci.h"
diff --git a/test/gatt_client/le_central.c b/test/gatt_client/le_central.c
index f33a0f6c2..a29803bfe 100644
--- a/test/gatt_client/le_central.c
+++ b/test/gatt_client/le_central.c
@@ -15,7 +15,7 @@
 #include "CppUTest/CommandLineTestRunner.h"
 #include "CppUTestExt/MockSupport.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 
 #include "btstack_memory.h"
 #include "hci.h"
diff --git a/test/hfp/Makefile b/test/hfp/Makefile
index b21eb3bfb..8e4263c55 100644
--- a/test/hfp/Makefile
+++ b/test/hfp/Makefile
@@ -17,7 +17,7 @@ COMMON = \
     btstack_run_loop_posix.c    \
     btstack_util.c			    \
     hci.c			            \
-    hci_cmds.c		            \
+    hci_cmd.c		            \
     hci_dump.c		            \
     l2cap.c			            \
     l2cap_signaling.c 			\
@@ -34,7 +34,7 @@ MOCK = \
 	test_sequences.c            \
     btstack_linked_list.c	    \
     btstack_memory.c            \
-    hci_cmds.c					\
+    hci_cmd.c					\
     hci_dump.c     				\
     btstack_memory_pool.c       \
     remote_device_db_memory.c   \
diff --git a/test/hfp/hfp_ag_client_test.c b/test/hfp/hfp_ag_client_test.c
index c977616f2..8a2765344 100644
--- a/test/hfp/hfp_ag_client_test.c
+++ b/test/hfp/hfp_ag_client_test.c
@@ -51,7 +51,7 @@
 #include "CppUTest/TestHarness.h"
 #include "CppUTest/CommandLineTestRunner.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/test/hfp/hfp_hf_client_test.c b/test/hfp/hfp_hf_client_test.c
index 6a4887ccd..ae7b91d5c 100644
--- a/test/hfp/hfp_hf_client_test.c
+++ b/test/hfp/hfp_hf_client_test.c
@@ -51,7 +51,7 @@
 #include "CppUTest/TestHarness.h"
 #include "CppUTest/CommandLineTestRunner.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/test/pts/bnep_test.c b/test/pts/bnep_test.c
index 2501a6696..942063ae4 100644
--- a/test/pts/bnep_test.c
+++ b/test/pts/bnep_test.c
@@ -55,7 +55,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/test/pts/classic_test.c b/test/pts/classic_test.c
index a754c117e..ad55e9416 100644
--- a/test/pts/classic_test.c
+++ b/test/pts/classic_test.c
@@ -49,7 +49,7 @@
 #include <string.h>
 #include <unistd.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/test/pts/hfp_ag_test.c b/test/pts/hfp_ag_test.c
index 59a456c9f..08edd4ecf 100644
--- a/test/pts/hfp_ag_test.c
+++ b/test/pts/hfp_ag_test.c
@@ -54,7 +54,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/test/pts/hfp_hf_test.c b/test/pts/hfp_hf_test.c
index 7faaa8648..bd3b57867 100644
--- a/test/pts/hfp_hf_test.c
+++ b/test/pts/hfp_hf_test.c
@@ -57,7 +57,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/test/pts/hfp_test.c b/test/pts/hfp_test.c
index 0cd4600d2..0464f96be 100644
--- a/test/pts/hfp_test.c
+++ b/test/pts/hfp_test.c
@@ -49,7 +49,7 @@
 #include <string.h>
 
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/test/pts/hsp_ag_test.c b/test/pts/hsp_ag_test.c
index 64675d5b1..e14472aca 100644
--- a/test/pts/hsp_ag_test.c
+++ b/test/pts/hsp_ag_test.c
@@ -54,7 +54,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/test/pts/hsp_hs_test.c b/test/pts/hsp_hs_test.c
index 6bbae9e63..952d38498 100644
--- a/test/pts/hsp_hs_test.c
+++ b/test/pts/hsp_hs_test.c
@@ -58,7 +58,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 #include "classic/sdp_util.h"
 
diff --git a/test/pts/l2cap_test.c b/test/pts/l2cap_test.c
index bfbf804fe..48487944a 100644
--- a/test/pts/l2cap_test.c
+++ b/test/pts/l2cap_test.c
@@ -49,7 +49,7 @@
 #include <string.h>
 #include <unistd.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/test/pts/sco_loopback.c b/test/pts/sco_loopback.c
index f9867d778..b3441f855 100644
--- a/test/pts/sco_loopback.c
+++ b/test/pts/sco_loopback.c
@@ -46,7 +46,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "hci.h"
 #include "btstack_debug.h"
  
diff --git a/test/sdp_client/general_sdp_query.c b/test/sdp_client/general_sdp_query.c
index c1c550174..db878fd11 100644
--- a/test/sdp_client/general_sdp_query.c
+++ b/test/sdp_client/general_sdp_query.c
@@ -12,7 +12,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/test/sdp_client/sdp_rfcomm_query.c b/test/sdp_client/sdp_rfcomm_query.c
index 062bb6f5b..fe08b782a 100644
--- a/test/sdp_client/sdp_rfcomm_query.c
+++ b/test/sdp_client/sdp_rfcomm_query.c
@@ -13,7 +13,7 @@
 #include <string.h>
 
 #include "classic/sdp_query_rfcomm.h"
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/test/sdp_client/service_attribute_search_query.c b/test/sdp_client/service_attribute_search_query.c
index c502d0feb..c89398d3a 100644
--- a/test/sdp_client/service_attribute_search_query.c
+++ b/test/sdp_client/service_attribute_search_query.c
@@ -12,7 +12,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/test/sdp_client/service_search_query.c b/test/sdp_client/service_search_query.c
index 7855130b3..b9fda8360 100644
--- a/test/sdp_client/service_search_query.c
+++ b/test/sdp_client/service_search_query.c
@@ -12,7 +12,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_run_loop.h"
 
 #include "hci.h"
diff --git a/test/security_manager/Makefile b/test/security_manager/Makefile
index 9023bda2a..0710e7bf3 100644
--- a/test/security_manager/Makefile
+++ b/test/security_manager/Makefile
@@ -18,7 +18,7 @@ COMMON = \
     btstack_memory_pool.c		\
     btstack_run_loop.c			\
     btstack_run_loop_posix.c    \
-    hci_cmds.c					\
+    hci_cmd.c					\
     hci_dump.c					\
     le_device_db_memory.c       \
     mock.c 				        \
diff --git a/test/security_manager/security_manager.c b/test/security_manager/security_manager.c
index 475c6f10a..bffbb4584 100644
--- a/test/security_manager/security_manager.c
+++ b/test/security_manager/security_manager.c
@@ -16,7 +16,7 @@
 
 #include "btstack_run_loop_posix.h"
 
-#include "hci_cmds.h"
+#include "hci_cmd.h"
 #include "btstack_util.h"
 
 #include "btstack_memory.h"
diff --git a/tool/generate.py b/tool/generate.py
index 9093bc64f..39fdacbc5 100755
--- a/tool/generate.py
+++ b/tool/generate.py
@@ -132,8 +132,8 @@ java_event_to_string = \
 # global variables/defines
 package='com.bluekitchen.btstack'
 gen_path = 'gen/' + package.replace('.', '/')
-hci_cmds_h_path = '../../src/hci_cmds.h'
-hci_cmds_c_path = '../../src/hci_cmds.c'
+hci_cmds_h_path = '../../src/hci_cmd.h'
+hci_cmds_c_path = '../../src/hci_cmd.c'
 daemon_cmds_c_path = '../../platform/daemon/daemon_cmds.c'
 hci_h_path = '../../src/hci.h'
 bluetooth_h_path = '../../src/bluetooth.h'
@@ -435,7 +435,7 @@ def parse_events(path):
                 format = None
     return (events, le_events, event_types)
 
 # read defines from hci_cmds.h and hci.h
 read_defines(hci_cmds_h_path)
 read_defines(hci_h_path)
 read_defines(bluetooth_h_path)
@@ -435,7 +435,7 @@ def parse_events(path):
     return (events, le_events, event_types)
 
-# read defines from hci_cmds.h and hci.h
+# read defines from hci_cmd.h and hci.h
 read_defines(hci_cmds_h_path)
 read_defines(hci_h_path)